# Tears of Steel Source Media

___
The sample media reference in this repository is based on the open source media project _Tears of Steel_ sponsored by
the Blender Foundation, a 12-minute short film created using open source software and released under the Creative
Commons Attribution 3.0 license. The _Tears of Steel_ project page can be found here: [_Tears of
Steel_ Project Page](https://mango.blender.org/).

**Please Note:** These media files are not ideal mezzanine files, but are short and easily accessible for testing and
demonstration purposes. Other original mezzanine files are available for download from the Blender Foundation website
for more advanced prototyping.

# Required Media Files

The primary media download page for the _Tears of Steel_ project can be found here:

- [Tears of Steel Media Download Page](https://mango.blender.org/download/)

## Video Mezzanine File with English 2.0 Sound Field

The mezzanine video is provided as a 4K AVC 8-bit 4:2:0 24fps file in a QuickTime wrapper with English 2.0 AAC LC audio.
It can be which can be downloaded here:

- [tearsofsteel_4k.mov](https://ftp.nluug.nl/pub/graphics/blender/demo/movies/ToS/tearsofsteel_4k.mov)

## External English 5.1 Sound Field Audio File

The English 5.1 sound field is provided by an external audio file which can be downloaded here:

- [Surround-TOS_DVDSURROUND-Dolby 5.1.ac3](https://ftp.nluug.nl/pub/graphics/blender/demo/movies/ToS/Surround-TOS_DVDSURROUND-Dolby%205.1.ac3)

## External English Subtitles File

The English subtitles are provided by an external SRT format subtitle file which can be downloaded here:

- [TOS-en.srt](https://ftp.nluug.nl/pub/graphics/blender/demo/movies/ToS/subtitles/TOS-en.srt)

**Please Note:** Additional subtitles are available on the _Tears of Steel_ media download page.